@@ -23,6 +23,10 @@ class TestPandasIntegration(unittest.TestCase):
     """Tests of Pandas integration features."""
     # TODO: test weirder archives (encoding, lime termination, ...)
 
+    def test_missing_extension_path(self):
+        with self.assertRaises(InvalidArchive):
+            DwCAReader(sample_data_path('dwca-missing-extension-details'))
+
     @patch('dwca.vendor._has_pandas', False)
     def test_pd_read_pandas_unavailable(self):
         with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
@@ -105,6 +109,11 @@ class TestPandasIntegration(unittest.TestCase):
 class TestDwCAReader(unittest.TestCase):
     # TODO: Move row-oriented tests to another test class
     """Unit tests for DwCAReader class."""
+    def test_partial_default(self):
+        with DwCAReader(sample_data_path('dwca-partial-default.zip')) as dwca:
+            self.assertEqual(dwca.rows[0].data[qn('country')], 'France')  # Value comes from data file
+            self.assertEqual(dwca.rows[1].data[qn('country')], 'Belgium')  # Value is field default
+
     def test_core_file_location(self):
         with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             self.assertEqual(dwca.core_file_location, 'occurrence.txt')
