@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 try:
-    import pandas
+    import pandas  # noqa
     _has_pandas = True
 except ImportError:
-    _has_pandas = False
\ No newline at end of file
+    _has_pandas = False
